intelmq.bots.experts.rdap package — intelmq 3.0.0.alpha.1 documentation

# intelmq.bots.experts.rdap package

## Submodules

## intelmq.bots.experts.rdap.expert module

`intelmq.bots.experts.rdap.expert.` `BOT`

  alias of `intelmq.bots.experts.rdap.expert.RDAPExpertBot`

class `intelmq.bots.experts.rdap.expert.` `RDAPExpertBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`, `intelmq.lib.mixins.cache.CacheMixin`

  Get RDAP data

  `init`()
  `overwrite`: bool = True
  `parse_entities`(vcardArray) → list
  `process`()
  `rdap_bootstrapped_servers`: dict = {}
  `rdap_order`: list = ['abuse', 'technical', 'administrative', 'registrant', 'registrar']
  `redis_cache_db`: int = 8
  `redis_cache_host`: str = '127.0.0.1'
  `redis_cache_password`: str = None
  `redis_cache_port`: int = 6379
  `redis_cache_ttl`: int = 86400

## Module contents